@@ -8,7 +8,7 @@
  *
  *
  * IDENTIFICATION
- *	  $Header: /usr/local/cvsroot/pgsql/src/backend/catalog/heap.c,v 1.125 2000/04/12 17:14:55 momjian Exp $
+ *	  $Header: /home/projects/pgsql/cvsroot/pgsql/src/backend/catalog/heap.c,v 1.128 2000/05/25 21:25:32 tgl Exp $
  *
  *
  * INTERFACE ROUTINES
@@ -62,6 +62,7 @@
 #include "storage/smgr.h"
 #include "tcop/tcopprot.h"
 #include "utils/builtins.h"
+#include "utils/catcache.h"
 #include "utils/portal.h"
 #include "utils/relcache.h"
 #include "utils/syscache.h"
@@ -184,18 +185,16 @@ heap_create(char *relname,
 			bool istemp,
 			bool storage_create)
 {
+	static unsigned int uniqueId = 0;
+
 	int			i;
 	Oid			relid;
 	Relation	rel;
 	int			len;
 	bool		nailme = false;
 	int			natts = tupDesc->natts;
-	static unsigned int uniqueId = 0;
-
-	extern GlobalMemory CacheCxt;
 	MemoryContext oldcxt;
 
-
 	/* ----------------
 	 *	sanity checks
 	 * ----------------
@@ -1197,8 +1196,6 @@ RelationTruncateIndexes(Relation heapRelation)
 		 * dirty, they're just dropped without bothering to flush to disk.
 		 */
 		ReleaseRelationBuffers(currentIndex);
-		if (FlushRelationBuffers(currentIndex, (BlockNumber) 0, false) < 0)
-			elog(ERROR, "RelationTruncateIndexes: unable to flush index from buffer pool");
 
 		/* Now truncate the actual data and set blocks to zero */
 		smgrtruncate(DEFAULT_SMGR, currentIndex, 0);
@@ -1266,8 +1263,6 @@ heap_truncate(char *relname)
 	 */
 
 	ReleaseRelationBuffers(rel);
-	if (FlushRelationBuffers(rel, (BlockNumber) 0, false) < 0)
-		elog(ERROR, "heap_truncate: unable to flush relation from buffer pool");
 
 	/* Now truncate the actual data and set blocks to zero */
 
@@ -1544,7 +1539,7 @@ heap_drop_with_catalog(const char *relname)
 	DeleteRelationTuple(rel);
 
 	/*
-	 * release dirty buffers of this relation
+	 * release dirty buffers of this relation; don't bother to write them
 	 */
 	ReleaseRelationBuffers(rel);
 
@@ -1583,12 +1578,15 @@ heap_drop_with_catalog(const char *relname)
 void
 heap_drop(Relation rel)
 {
+	Oid			rid = RelationGetRelid(rel);
+
 	ReleaseRelationBuffers(rel);
 	if (!(rel->rd_isnoname) || !(rel->rd_unlinked))
 		smgrunlink(DEFAULT_SMGR, rel);
 	rel->rd_unlinked = TRUE;
 	heap_close(rel, NoLock);
 	RemoveFromNoNameRelList(rel);
+	RelationForgetRelation(rid);
 }
 
 
